formaldict
########################################################################

Documentation
=============

`View the formaldict docs here
<https://formaldict.readthedocs.io/>`_.

Installation
============

Install formaldict with::

    pip3 install formaldict


Contributing Guide
==================

For information on setting up formaldict for development and
contributing changes, view `CONTRIBUTING.rst <CONTRIBUTING.rst>`_.


Primary Authors
===============

- @wesleykendall (Wes Kendall)
